Enum rnix::NixLanguage
source · [−]pub enum NixLanguage {}Trait Implementations
sourceimpl Clone for NixLanguage
impl Clone for NixLanguage
sourcefn clone(&self) -> NixLanguage
fn clone(&self) -> NixLanguage
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for NixLanguage
impl Debug for NixLanguage
sourceimpl Hash for NixLanguage
impl Hash for NixLanguage
sourceimpl Language for NixLanguage
impl Language for NixLanguage
type Kind = SyntaxKind
fn kind_from_raw(raw: SyntaxKind) -> Self::Kind
fn kind_to_raw(kind: Self::Kind) -> SyntaxKind
sourceimpl Ord for NixLanguage
impl Ord for NixLanguage
sourceimpl PartialEq<NixLanguage> for NixLanguage
impl PartialEq<NixLanguage> for NixLanguage
sourceimpl PartialOrd<NixLanguage> for NixLanguage
impl PartialOrd<NixLanguage> for NixLanguage
sourcefn partial_cmp(&self, other: &NixLanguage) -> Option<Ordering>
fn partial_cmp(&self, other: &NixLanguage) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Copy for NixLanguage
impl Eq for NixLanguage
impl StructuralEq for NixLanguage
impl StructuralPartialEq for NixLanguage